@@ -5,7 +5,7 @@ from typing import Any, Dict
 import click
 
 from .click_common import command, format_output
-from .device import Device
+from .device import Device, DeviceStatus
 from .exceptions import DeviceException
 
 _LOGGER = logging.getLogger(__name__)
@@ -15,7 +15,7 @@ class CeilException(DeviceException):
     pass
 
 
-class CeilStatus:
+class CeilStatus(DeviceStatus):
     """Container for status reports from Xiaomi Philips LED Ceiling Lamp."""
 
     def __init__(self, data: Dict[str, Any]) -> None:
@@ -66,27 +66,6 @@ class CeilStatus:
         """Automatic color temperature state."""
         return self.data["ac"] == 1
 
-    def __repr__(self) -> str:
-        s = (
-            "<CeilStatus power=%s, "
-            "brightness=%s, "
-            "color_temperature=%s, "
-            "scene=%s, "
-            "delay_off_countdown=%s, "
-            "smart_night_light=%s, "
-            "automatic_color_temperature=%s>"
-            % (
-                self.power,
-                self.brightness,
-                self.color_temperature,
-                self.scene,
-                self.delay_off_countdown,
-                self.smart_night_light,
-                self.automatic_color_temperature,
-            )
-        )
-        return s
-
 
 class Ceil(Device):
     """Main class representing Xiaomi Philips LED Ceiling Lamp."""
@@ -179,7 +158,7 @@ class Ceil(Device):
         default_output=format_output("Setting fixed scene to {number}"),
     )
     def set_scene(self, number: int):
-        """Set a fixed scene. 4 fixed scenes are available (1-4)"""
+        """Set a fixed scene (1-4)."""
         if number < 1 or number > 4:
             raise CeilException("Invalid fixed scene number: %s" % number)
 
