@@ -7,7 +7,7 @@ from typing import Any, Dict
 import click
 
 from .click_common import EnumType, command, format_output
-from .device import Device
+from .device import Device, DeviceStatus
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -65,7 +65,7 @@ CONST_HIGH_SENSITIVITY = [MotionDetectionSensitivity.High] * 32
 CONST_LOW_SENSITIVITY = [MotionDetectionSensitivity.Low] * 32
 
 
-class CameraStatus:
+class CameraStatus(DeviceStatus):
     """Container for status reports from the Xiaomi Chuangmi Camera."""
 
     def __init__(self, data: Dict[str, Any]) -> None:
@@ -144,40 +144,6 @@ class CameraStatus:
         """Unknown."""
         return self.data["mini_level"]
 
-    def __repr__(self) -> str:
-        s = (
-            "<CameraStatus "
-            "power=%s, "
-            "motion_record=%s, "
-            "light=%s, "
-            "full_color=%s, "
-            "flip=%s, "
-            "improve_program=%s, "
-            "wdr=%s, "
-            "track=%s, "
-            "watermark=%s, "
-            "sdcard_status=%s, "
-            "max_client=%s, "
-            "night_mode=%s, "
-            "mini_level=%s>"
-            % (
-                self.power,
-                self.motion_record,
-                self.light,
-                self.full_color,
-                self.flip,
-                self.improve_program,
-                self.wdr,
-                self.track,
-                self.sdcard_status,
-                self.watermark,
-                self.max_client,
-                self.night_mode,
-                self.mini_level,
-            )
-        )
-        return s
-
 
 class ChuangmiCamera(Device):
     """Main class representing the Xiaomi Chuangmi Camera."""
@@ -369,7 +335,7 @@ class ChuangmiCamera(Device):
         notify: int = 1,
         interval: int = 5,
     ):
-        """Set home monitoring configuration"""
+        """Set home monitoring configuration."""
         return self.send(
             "setAlarmConfig",
             [mode, start_hour, start_minute, end_hour, end_minute, notify, interval],
@@ -377,12 +343,12 @@ class ChuangmiCamera(Device):
 
     @command(default_output=format_output("Clearing NAS directory"))
     def clear_nas_dir(self):
-        """Clear NAS directory"""
+        """Clear NAS directory."""
         return self.send("nas_clear_dir", [[]])
 
     @command(default_output=format_output("Getting NAS config info"))
     def get_nas_config(self):
-        """Get NAS config info"""
+        """Get NAS config info."""
         return self.send("nas_get_config", {})
 
     @command(
@@ -395,11 +361,13 @@ class ChuangmiCamera(Device):
     def set_nas_config(
         self,
         state: NASState,
-        share={},
+        share=None,
         sync_interval: NASSyncInterval = NASSyncInterval.Realtime,
         video_retention_time: NASVideoRetentionTime = NASVideoRetentionTime.Week,
     ):
-        """Set NAS configuration"""
+        """Set NAS configuration."""
+        if share is None:
+            share = {}
         return self.send(
             "nas_set_config",
             {
