@@ -95,6 +95,7 @@ class WaterFlow(enum.Enum):
 
 ROCKROBO_V1 = "rockrobo.vacuum.v1"
 ROCKROBO_S5 = "roborock.vacuum.s5"
+ROCKROBO_S6 = "roborock.vacuum.s6"
 ROCKROBO_S6_MAXV = "roborock.vacuum.a10"
 
 
@@ -152,6 +153,7 @@ class Vacuum(Device):
 
         SKIP_PAUSE = [
             ROCKROBO_S5,
+            ROCKROBO_S6,
             ROCKROBO_S6_MAXV,
         ]
 
